/**
 * Copyright (c) 2007-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.clientserverapi.topology;

import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.clientserverapi.configuration.ContainerConfiguration;
import org.ow2.petals.clientserverapi.topology.exception.AddContainerException;


/**
 * Client interface of the service 'Topology'
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface TopologyService {

    /**
     * Add the given container into the given sub-domain of the topology.
     * 
     * @param addedContainer
     *            the container to add to the current topology
     * @param subdomainName
     *            the sub-domain of the topology in which the container must be
     *            added
     * 
     * @throws AddContainerException
     *             Failed to add the container to the current topology
     * @throws PetalsException
     *             Any other error
     */
    void addContainerConfiguration(final ContainerConfiguration addedContainer,
            final String subdomainName) throws AddContainerException, PetalsException;

    /**
     * Add the given container into the given sub-domain of the topology
     * validating the topology
     * 
     * @param addedContainer
     *            the container to add to the current topology
     * @param subdomainName
     *            the sub-domain of the topology in which the container must be
     *            added
     * @param validateTopologyIf
     *            <code>true</code>, the topology is validated.
     * 
     * @throws AddContainerException
     *             Failed to add the container to the current topology
     * @throws PetalsException
     *             Any other error
     */
    void addContainerConfiguration(ContainerConfiguration addedContainer,
            final String subdomainName, final boolean validateTopology)
            throws AddContainerException, PetalsException;

}
